@@ -17,7 +17,7 @@ ROUTE_METHODS = [POST, PUT, PATCH, DELETE, GET, HEAD, OPTIONS, TRACE]
 THROTTLED_FUNCTION = "__throttled_endpoint__"
 ROUTE_FUNCTION = "__route_function__"
 
-ROUTE_CONTEXT_VAR: contextvars.ContextVar[
-    t.Optional["RouteContext"]
-] = contextvars.ContextVar("ROUTE_CONTEXT_VAR")
+ROUTE_CONTEXT_VAR: contextvars.ContextVar[t.Optional["RouteContext"]] = (
+    contextvars.ContextVar("ROUTE_CONTEXT_VAR")
+)
 ROUTE_CONTEXT_VAR.set(None)
